@@ -39,8 +39,9 @@ typedef struct
 } SIMPLE_TIME;
 
 int		copy_and_convert_field_bindinfo(StatementClass *stmt, OID field_type, void *value, int col);
-int copy_and_convert_field(StatementClass *stmt, OID field_type, void *value, SQLSMALLINT fCType,
-			PTR rgbValue, SQLLEN cbValueMax, SQLLEN *pcbValue);
+int	copy_and_convert_field(StatementClass *stmt, OID field_type,
+			void *value, SQLSMALLINT fCType, PTR rgbValue,
+			SQLLEN cbValueMax, SQLLEN *pcbValue, SQLLEN *pIndicator);
 
 int		copy_statement_with_parameters(StatementClass *stmt, BOOL);
 BOOL		convert_money(const char *s, char *sout, size_t soutmax);
@@ -53,6 +54,7 @@ size_t		convert_from_pgbinary(const UCHAR *value, UCHAR *rgbValue, SQLLEN cbValu
 SQLLEN		pg_hex2bin(const UCHAR *in, UCHAR *out, SQLLEN len);
 int convert_lo(StatementClass *stmt, const void *value, SQLSMALLINT fCType,
 	 PTR rgbValue, SQLLEN cbValueMax, SQLLEN *pcbValue);
+Int4		findTag(const char *str, char dollar_quote, int ccsc);
 
 #ifdef	__cplusplus
 }
