@@ -639,7 +639,9 @@ QR_close(QResultClass *self)
 
 			snprintf(buf, sizeof(buf), "close \"%s\"", QR_get_cursor(self));
 			/* End the transaction if there are no cursors left on this conn */
-			if (CC_is_in_autocommit(conn) && CC_cursor_count(conn) <= 1)
+			if (CC_is_in_trans(conn) &&
+			    CC_is_in_autocommit(conn) &&
+			    CC_cursor_count(conn) <= 1)
 			{
 				mylog("QResult: END transaction on conn=%p\n", conn);
 				strncat(buf, ";commit", sizeof(buf));
@@ -866,7 +868,7 @@ inolog("cache=%d rowset=%d movement=" FORMAT_ULEN "\n", self->cache_size, req_si
 			return -1;
 		}
 		moved = movement;
-		if (sscanf(mres->command, "MOVE %lu", &moved) > 0)
+		if (sscanf(mres->command, "MOVE " FORMAT_ULEN, &moved) > 0)
 		{
 inolog("moved=%d ? " FORMAT_ULEN "\n", moved, movement);
         		if (moved < movement)
@@ -917,7 +919,7 @@ inolog("back_offset=%d and move_offset=%d\n", back_offset, self->move_offset);
 							return -1;
 						}
 
-						if (sscanf(mres->command, "MOVE %lu", &mback) > 0)
+						if (sscanf(mres->command, "MOVE " FORMAT_ULEN, &mback) > 0)
 						{
 							if (mback < bmovement)
 								mback++;
